<#
.SYNOPSIS
Sample script to show handling CSV files in PowerShell.

.PARAMETER Path
Path to the CSV file containing the orders to process

.PARAMETER $Customer
If given, process only the orders from this customer

.DESCRIPTION
Gets a list of orders in a CSV file, and summs their price

#>

param(
	[Parameter(Mandatory=$true,Position=0)][string] $Path,
	[Parameter(Mandatory=$false)][int] $Customer = -1
)

# Check that the input path exists and it is a file
if (! (Test-Path $Path)) {
	throw "$Path does not exists, correct -Path parameter!"
}
if (! (Test-Path $Path -PathType Leaf)) {
	throw "$Path is not a file, correct -Path parameter!"
}

$sum = 0

# Process all lines in the CSV
Import-Csv $Path | Foreach-Object {
	# If $Customer parameter was not supplied, its value would be -1
	# In this case sum all orders, otherwise only those, whose CustomerID 
	# matches the given ID.
	if ( ! (($Customer -ne -1) -and ($Customer -ne $_.CustomerID)) ) {
		$sum += $_.FullPrice
	}
}

Write-Output $sum